Class: SoilSidekick::BeginnerGuidanceRequest

Inherits:
ApiModelBase show all
Defined in:
lib/soilsidekick/models/beginner_guidance_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BeginnerGuidanceRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::BeginnerGuidanceRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::BeginnerGuidanceRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'question')
    self.question = attributes[:'question']
  else
    self.question = nil
  end

  if attributes.key?(:'plant_context')
    self.plant_context = attributes[:'plant_context']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'user_expertise')
    self.user_expertise = attributes[:'user_expertise']
  else
    self.user_expertise = 'complete_beginner'
  end
end

Instance Attribute Details

#locationObject

Returns the value of attribute location.



23
24
25
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 23

def location
  @location
end

#plant_contextObject

Returns the value of attribute plant_context.



21
22
23
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 21

def plant_context
  @plant_context
end

#questionObject

User’s plant question in natural language



19
20
21
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 19

def question
  @question
end

#user_expertiseObject

User’s self-assessed expertise level



26
27
28
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 26

def user_expertise
  @user_expertise
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 51

def self.attribute_map
  {
    :'question' => :'question',
    :'plant_context' => :'plant_context',
    :'location' => :'location',
    :'user_expertise' => :'user_expertise'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 191

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 71

def self.openapi_types
  {
    :'question' => :'String',
    :'plant_context' => :'BeginnerGuidanceRequestPlantContext',
    :'location' => :'BeginnerGuidanceRequestLocation',
    :'user_expertise' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



167
168
169
170
171
172
173
174
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 167

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      question == o.question &&
      plant_context == o.plant_context &&
      location == o.location &&
      user_expertise == o.user_expertise
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 178

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



184
185
186
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 184

def hash
  [question, plant_context, location, user_expertise].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



125
126
127
128
129
130
131
132
133
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @question.nil?
    invalid_properties.push('invalid value for "question", question cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
141
142
143
# File 'lib/soilsidekick/models/beginner_guidance_request.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @question.nil?
  user_expertise_validator = EnumAttributeValidator.new('String', ["complete_beginner", "some_experience", "intermediate"])
  return false unless user_expertise_validator.valid?(@user_expertise)
  true
end