Class: SoilSidekick::CalculateCarbonCreditsRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/soilsidekick/models/calculate_carbon_credits_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CalculateCarbonCreditsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::CalculateCarbonCreditsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::CalculateCarbonCreditsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'field_name')
    self.field_name = attributes[:'field_name']
  else
    self.field_name = nil
  end

  if attributes.key?(:'field_size_acres')
    self.field_size_acres = attributes[:'field_size_acres']
  else
    self.field_size_acres = nil
  end

  if attributes.key?(:'soil_organic_matter')
    self.soil_organic_matter = attributes[:'soil_organic_matter']
  end

  if attributes.key?(:'soil_analysis_id')
    self.soil_analysis_id = attributes[:'soil_analysis_id']
  end

  if attributes.key?(:'verification_type')
    self.verification_type = attributes[:'verification_type']
  end
end

Instance Attribute Details

#field_nameObject

Name of the field



19
20
21
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 19

def field_name
  @field_name
end

#field_size_acresObject

Field size in acres



22
23
24
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 22

def field_size_acres
  @field_size_acres
end

#soil_analysis_idObject

Reference to existing soil analysis



28
29
30
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 28

def soil_analysis_id
  @soil_analysis_id
end

#soil_organic_matterObject

Soil organic matter percentage



25
26
27
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 25

def soil_organic_matter
  @soil_organic_matter
end

#verification_typeObject

Returns the value of attribute verification_type.



30
31
32
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 30

def verification_type
  @verification_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 55

def self.attribute_map
  {
    :'field_name' => :'field_name',
    :'field_size_acres' => :'field_size_acres',
    :'soil_organic_matter' => :'soil_organic_matter',
    :'soil_analysis_id' => :'soil_analysis_id',
    :'verification_type' => :'verification_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 226

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 76

def self.openapi_types
  {
    :'field_name' => :'String',
    :'field_size_acres' => :'Float',
    :'soil_organic_matter' => :'Float',
    :'soil_analysis_id' => :'String',
    :'verification_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



201
202
203
204
205
206
207
208
209
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 201

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      field_name == o.field_name &&
      field_size_acres == o.field_size_acres &&
      soil_organic_matter == o.soil_organic_matter &&
      soil_analysis_id == o.soil_analysis_id &&
      verification_type == o.verification_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


213
214
215
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 213

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



219
220
221
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 219

def hash
  [field_name, field_size_acres, soil_organic_matter, soil_analysis_id, verification_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 135

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @field_name.nil?
    invalid_properties.push('invalid value for "field_name", field_name cannot be nil.')
  end

  if @field_size_acres.nil?
    invalid_properties.push('invalid value for "field_size_acres", field_size_acres cannot be nil.')
  end

  if @field_size_acres < 0.1
    invalid_properties.push('invalid value for "field_size_acres", must be greater than or equal to 0.1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 248

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
160
161
162
163
# File 'lib/soilsidekick/models/calculate_carbon_credits_request.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @field_name.nil?
  return false if @field_size_acres.nil?
  return false if @field_size_acres < 0.1
  verification_type_validator = EnumAttributeValidator.new('String', ["self_reported", "third_party", "satellite"])
  return false unless verification_type_validator.valid?(@verification_type)
  true
end