Class: SoilSidekick::CarbonCreditCalculationCreditRecord

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CarbonCreditCalculationCreditRecord

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::CarbonCreditCalculationCreditRecord` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::CarbonCreditCalculationCreditRecord`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'field_name')
    self.field_name = attributes[:'field_name']
  end

  if attributes.key?(:'field_size_acres')
    self.field_size_acres = attributes[:'field_size_acres']
  end

  if attributes.key?(:'credits_earned')
    self.credits_earned = attributes[:'credits_earned']
  end

  if attributes.key?(:'verification_status')
    self.verification_status = attributes[:'verification_status']
  end
end

Instance Attribute Details

#credits_earnedObject

Returns the value of attribute credits_earned.



24
25
26
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 24

def credits_earned
  @credits_earned
end

#field_nameObject

Returns the value of attribute field_name.



20
21
22
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 20

def field_name
  @field_name
end

#field_size_acresObject

Returns the value of attribute field_size_acres.



22
23
24
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 22

def field_size_acres
  @field_size_acres
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 18

def id
  @id
end

#verification_statusObject

Returns the value of attribute verification_status.



26
27
28
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 26

def verification_status
  @verification_status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 51

def self.attribute_map
  {
    :'id' => :'id',
    :'field_name' => :'field_name',
    :'field_size_acres' => :'field_size_acres',
    :'credits_earned' => :'credits_earned',
    :'verification_status' => :'verification_status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 179

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 72

def self.openapi_types
  {
    :'id' => :'String',
    :'field_name' => :'String',
    :'field_size_acres' => :'Float',
    :'credits_earned' => :'Float',
    :'verification_status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



154
155
156
157
158
159
160
161
162
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 154

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      field_name == o.field_name &&
      field_size_acres == o.field_size_acres &&
      credits_earned == o.credits_earned &&
      verification_status == o.verification_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


166
167
168
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 166

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



172
173
174
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 172

def hash
  [id, field_name, field_size_acres, credits_earned, verification_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 201

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
139
140
# File 'lib/soilsidekick/models/carbon_credit_calculation_credit_record.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  verification_status_validator = EnumAttributeValidator.new('String', ["pending", "verified"])
  return false unless verification_status_validator.valid?(@verification_status)
  true
end