Class: SoilSidekick::DynamicCareRequestEnvironment

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/soilsidekick/models/dynamic_care_request_environment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DynamicCareRequestEnvironment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::DynamicCareRequestEnvironment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::DynamicCareRequestEnvironment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'light_exposure')
    self.light_exposure = attributes[:'light_exposure']
  end

  if attributes.key?(:'humidity_level')
    self.humidity_level = attributes[:'humidity_level']
  end
end

Instance Attribute Details

#humidity_levelObject

Approximate indoor humidity if applicable



21
22
23
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 21

def humidity_level
  @humidity_level
end

#light_exposureObject

Returns the value of attribute light_exposure.



18
19
20
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 18

def light_exposure
  @light_exposure
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 46

def self.attribute_map
  {
    :'light_exposure' => :'light_exposure',
    :'humidity_level' => :'humidity_level'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 165

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 64

def self.openapi_types
  {
    :'light_exposure' => :'String',
    :'humidity_level' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



143
144
145
146
147
148
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 143

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      light_exposure == o.light_exposure &&
      humidity_level == o.humidity_level
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


152
153
154
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 152

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



158
159
160
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 158

def hash
  [light_exposure, humidity_level].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



104
105
106
107
108
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 104

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 187

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



112
113
114
115
116
117
118
119
# File 'lib/soilsidekick/models/dynamic_care_request_environment.rb', line 112

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  light_exposure_validator = EnumAttributeValidator.new('String', ["full_sun", "partial_sun", "partial_shade", "full_shade", "artificial"])
  return false unless light_exposure_validator.valid?(@light_exposure)
  humidity_level_validator = EnumAttributeValidator.new('String', ["low", "medium", "high"])
  return false unless humidity_level_validator.valid?(@humidity_level)
  true
end