Class: SoilSidekick::DynamicCareRequestLocation

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/soilsidekick/models/dynamic_care_request_location.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DynamicCareRequestLocation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 61

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::DynamicCareRequestLocation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::DynamicCareRequestLocation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'county_fips')
    self.county_fips = attributes[:'county_fips']
  else
    self.county_fips = nil
  end

  if attributes.key?(:'state_code')
    self.state_code = attributes[:'state_code']
  end

  if attributes.key?(:'indoor')
    self.indoor = attributes[:'indoor']
  end
end

Instance Attribute Details

#county_fipsObject

Returns the value of attribute county_fips.



18
19
20
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 18

def county_fips
  @county_fips
end

#indoorObject

Whether the plant is indoors



23
24
25
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 23

def indoor
  @indoor
end

#state_codeObject

Returns the value of attribute state_code.



20
21
22
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 20

def state_code
  @state_code
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



35
36
37
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 35

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



40
41
42
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 40

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
32
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 26

def self.attribute_map
  {
    :'county_fips' => :'county_fips',
    :'state_code' => :'state_code',
    :'indoor' => :'indoor'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 156

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



54
55
56
57
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 54

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



45
46
47
48
49
50
51
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 45

def self.openapi_types
  {
    :'county_fips' => :'String',
    :'state_code' => :'String',
    :'indoor' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



133
134
135
136
137
138
139
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 133

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      county_fips == o.county_fips &&
      state_code == o.state_code &&
      indoor == o.indoor
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


143
144
145
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 143

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



149
150
151
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 149

def hash
  [county_fips, state_code, indoor].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 92

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @county_fips.nil?
    invalid_properties.push('invalid value for "county_fips", county_fips cannot be nil.')
  end

  pattern = Regexp.new(/^[0-9]{5}$/)
  if @county_fips !~ pattern
    invalid_properties.push("invalid value for \"county_fips\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 178

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



109
110
111
112
113
114
# File 'lib/soilsidekick/models/dynamic_care_request_location.rb', line 109

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @county_fips.nil?
  return false if @county_fips !~ Regexp.new(/^[0-9]{5}$/)
  true
end