Class: SoilSidekick::GetLiveAgriculturalDataRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/soilsidekick/models/get_live_agricultural_data_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetLiveAgriculturalDataRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::GetLiveAgriculturalDataRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::GetLiveAgriculturalDataRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'county_fips')
    self.county_fips = attributes[:'county_fips']
  else
    self.county_fips = nil
  end

  if attributes.key?(:'data_types')
    if (value = attributes[:'data_types']).is_a?(Array)
      self.data_types = value
    end
  else
    self.data_types = nil
  end

  if attributes.key?(:'state_code')
    self.state_code = attributes[:'state_code']
  else
    self.state_code = nil
  end

  if attributes.key?(:'county_name')
    self.county_name = attributes[:'county_name']
  else
    self.county_name = nil
  end
end

Instance Attribute Details

#county_fipsObject

Returns the value of attribute county_fips.



18
19
20
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 18

def county_fips
  @county_fips
end

#county_nameObject

Returns the value of attribute county_name.



25
26
27
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 25

def county_name
  @county_name
end

#data_typesObject

Types of data to fetch



21
22
23
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 21

def data_types
  @data_types
end

#state_codeObject

Returns the value of attribute state_code.



23
24
25
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 23

def state_code
  @state_code
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 50

def self.attribute_map
  {
    :'county_fips' => :'county_fips',
    :'data_types' => :'data_types',
    :'state_code' => :'state_code',
    :'county_name' => :'county_name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 239

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 80

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 70

def self.openapi_types
  {
    :'county_fips' => :'String',
    :'data_types' => :'Array<String>',
    :'state_code' => :'String',
    :'county_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



215
216
217
218
219
220
221
222
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 215

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      county_fips == o.county_fips &&
      data_types == o.data_types &&
      state_code == o.state_code &&
      county_name == o.county_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


226
227
228
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 226

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



232
233
234
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 232

def hash
  [county_fips, data_types, state_code, county_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @county_fips.nil?
    invalid_properties.push('invalid value for "county_fips", county_fips cannot be nil.')
  end

  pattern = Regexp.new(/^[0-9]{5}$/)
  if @county_fips !~ pattern
    invalid_properties.push("invalid value for \"county_fips\", must conform to the pattern #{pattern}.")
  end

  if @data_types.nil?
    invalid_properties.push('invalid value for "data_types", data_types cannot be nil.')
  end

  if @state_code.nil?
    invalid_properties.push('invalid value for "state_code", state_code cannot be nil.')
  end

  if @state_code.to_s.length > 2
    invalid_properties.push('invalid value for "state_code", the character length must be smaller than or equal to 2.')
  end

  if @county_name.nil?
    invalid_properties.push('invalid value for "county_name", county_name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 261

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
167
168
169
170
171
172
# File 'lib/soilsidekick/models/get_live_agricultural_data_request.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @county_fips.nil?
  return false if @county_fips !~ Regexp.new(/^[0-9]{5}$/)
  return false if @data_types.nil?
  return false if @state_code.nil?
  return false if @state_code.to_s.length > 2
  return false if @county_name.nil?
  true
end