Class: SoilSidekick::LeafEnginesCompatibilityData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SoilSidekick::LeafEnginesCompatibilityData
- Defined in:
- lib/soilsidekick/models/leaf_engines_compatibility_data.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#breakdown ⇒ Object
Returns the value of attribute breakdown.
-
#climate_compatibility ⇒ Object
Returns the value of attribute climate_compatibility.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#overall_score ⇒ Object
Overall compatibility score (0-100).
-
#recommendations ⇒ Object
Returns the value of attribute recommendations.
-
#risk_level ⇒ Object
Returns the value of attribute risk_level.
-
#soil_compatibility ⇒ Object
Returns the value of attribute soil_compatibility.
-
#water_compatibility ⇒ Object
Returns the value of attribute water_compatibility.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LeafEnginesCompatibilityData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LeafEnginesCompatibilityData
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::LeafEnginesCompatibilityData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::LeafEnginesCompatibilityData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'overall_score') self.overall_score = attributes[:'overall_score'] end if attributes.key?(:'soil_compatibility') self.soil_compatibility = attributes[:'soil_compatibility'] end if attributes.key?(:'water_compatibility') self.water_compatibility = attributes[:'water_compatibility'] end if attributes.key?(:'climate_compatibility') self.climate_compatibility = attributes[:'climate_compatibility'] end if attributes.key?(:'breakdown') self.breakdown = attributes[:'breakdown'] end if attributes.key?(:'recommendations') if (value = attributes[:'recommendations']).is_a?(Array) self.recommendations = value end end if attributes.key?(:'risk_level') self.risk_level = attributes[:'risk_level'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end end |
Instance Attribute Details
#breakdown ⇒ Object
Returns the value of attribute breakdown.
27 28 29 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 27 def breakdown @breakdown end |
#climate_compatibility ⇒ Object
Returns the value of attribute climate_compatibility.
25 26 27 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 25 def climate_compatibility @climate_compatibility end |
#metadata ⇒ Object
Returns the value of attribute metadata.
33 34 35 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 33 def @metadata end |
#overall_score ⇒ Object
Overall compatibility score (0-100)
19 20 21 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 19 def overall_score @overall_score end |
#recommendations ⇒ Object
Returns the value of attribute recommendations.
29 30 31 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 29 def recommendations @recommendations end |
#risk_level ⇒ Object
Returns the value of attribute risk_level.
31 32 33 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 31 def risk_level @risk_level end |
#soil_compatibility ⇒ Object
Returns the value of attribute soil_compatibility.
21 22 23 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 21 def soil_compatibility @soil_compatibility end |
#water_compatibility ⇒ Object
Returns the value of attribute water_compatibility.
23 24 25 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 23 def water_compatibility @water_compatibility end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 58 def self.attribute_map { :'overall_score' => :'overall_score', :'soil_compatibility' => :'soil_compatibility', :'water_compatibility' => :'water_compatibility', :'climate_compatibility' => :'climate_compatibility', :'breakdown' => :'breakdown', :'recommendations' => :'recommendations', :'risk_level' => :'risk_level', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 209 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 82 def self.openapi_types { :'overall_score' => :'Float', :'soil_compatibility' => :'Float', :'water_compatibility' => :'Float', :'climate_compatibility' => :'Float', :'breakdown' => :'LeafEnginesCompatibilityDataBreakdown', :'recommendations' => :'Array<String>', :'risk_level' => :'String', :'metadata' => :'LeafEnginesCompatibilityDataMetadata' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 181 def ==(o) return true if self.equal?(o) self.class == o.class && overall_score == o.overall_score && soil_compatibility == o.soil_compatibility && water_compatibility == o.water_compatibility && climate_compatibility == o.climate_compatibility && breakdown == o.breakdown && recommendations == o.recommendations && risk_level == o.risk_level && == o. end |
#eql?(o) ⇒ Boolean
196 197 198 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 196 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
202 203 204 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 202 def hash [overall_score, soil_compatibility, water_compatibility, climate_compatibility, breakdown, recommendations, risk_level, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
154 155 156 157 158 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 154 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 231 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
162 163 164 165 166 167 |
# File 'lib/soilsidekick/models/leaf_engines_compatibility_data.rb', line 162 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' risk_level_validator = EnumAttributeValidator.new('String', ["low", "medium", "high"]) return false unless risk_level_validator.valid?(@risk_level) true end |