Class: SoilSidekick::SafeIdentificationIdentification
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SoilSidekick::SafeIdentificationIdentification
- Defined in:
- lib/soilsidekick/models/safe_identification_identification.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#environmental_probability ⇒ Object
Likelihood this plant exists in the given environment.
-
#growth_stage_detected ⇒ Object
Returns the value of attribute growth_stage_detected.
-
#primary_match ⇒ Object
Returns the value of attribute primary_match.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SafeIdentificationIdentification
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SafeIdentificationIdentification
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::SafeIdentificationIdentification` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::SafeIdentificationIdentification`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'primary_match') self.primary_match = attributes[:'primary_match'] end if attributes.key?(:'environmental_probability') self.environmental_probability = attributes[:'environmental_probability'] end if attributes.key?(:'growth_stage_detected') self.growth_stage_detected = attributes[:'growth_stage_detected'] end end |
Instance Attribute Details
#environmental_probability ⇒ Object
Likelihood this plant exists in the given environment
21 22 23 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 21 def environmental_probability @environmental_probability end |
#growth_stage_detected ⇒ Object
Returns the value of attribute growth_stage_detected.
23 24 25 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 23 def growth_stage_detected @growth_stage_detected end |
#primary_match ⇒ Object
Returns the value of attribute primary_match.
18 19 20 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 18 def primary_match @primary_match end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 48 def self.attribute_map { :'primary_match' => :'primary_match', :'environmental_probability' => :'environmental_probability', :'growth_stage_detected' => :'growth_stage_detected' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 162 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 67 def self.openapi_types { :'primary_match' => :'SafeIdentificationIdentificationPrimaryMatch', :'environmental_probability' => :'Float', :'growth_stage_detected' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
139 140 141 142 143 144 145 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 139 def ==(o) return true if self.equal?(o) self.class == o.class && primary_match == o.primary_match && environmental_probability == o.environmental_probability && growth_stage_detected == o.growth_stage_detected end |
#eql?(o) ⇒ Boolean
149 150 151 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 149 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
155 156 157 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 155 def hash [primary_match, environmental_probability, growth_stage_detected].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
112 113 114 115 116 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 112 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 184 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
120 121 122 123 124 125 |
# File 'lib/soilsidekick/models/safe_identification_identification.rb', line 120 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' growth_stage_detected_validator = EnumAttributeValidator.new('String', ["seedling", "juvenile", "mature", "flowering", "fruiting"]) return false unless growth_stage_detected_validator.valid?(@growth_stage_detected) true end |