Class: SoilSidekick::TurboQuantCapabilities

Inherits:
ApiModelBase show all
Defined in:
lib/soilsidekick/models/turbo_quant_capabilities.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TurboQuantCapabilities

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::TurboQuantCapabilities` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::TurboQuantCapabilities`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'supported')
    self.supported = attributes[:'supported']
  end

  if attributes.key?(:'recommended_model')
    self.recommended_model = attributes[:'recommended_model']
  end

  if attributes.key?(:'max_context_tokens')
    self.max_context_tokens = attributes[:'max_context_tokens']
  end

  if attributes.key?(:'estimated_kv_cache_gb')
    self.estimated_kv_cache_gb = attributes[:'estimated_kv_cache_gb']
  end

  if attributes.key?(:'kv_compression_ratio')
    self.kv_compression_ratio = attributes[:'kv_compression_ratio']
  end

  if attributes.key?(:'estimated_latency_ms')
    self.estimated_latency_ms = attributes[:'estimated_latency_ms']
  end

  if attributes.key?(:'runtime_tier')
    self.runtime_tier = attributes[:'runtime_tier']
  end
end

Instance Attribute Details

#estimated_kv_cache_gbObject

Estimated KV cache size in GB



28
29
30
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 28

def estimated_kv_cache_gb
  @estimated_kv_cache_gb
end

#estimated_latency_msObject

Returns the value of attribute estimated_latency_ms.



33
34
35
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 33

def estimated_latency_ms
  @estimated_latency_ms
end

#kv_compression_ratioObject

Compression ratio vs 16-bit baseline



31
32
33
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 31

def kv_compression_ratio
  @kv_compression_ratio
end

#max_context_tokensObject

Maximum context window feasible on this device



25
26
27
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 25

def max_context_tokens
  @max_context_tokens
end

Recommended model for the device



22
23
24
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 22

def recommended_model
  @recommended_model
end

#runtime_tierObject

Detected or recommended runtime



36
37
38
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 36

def runtime_tier
  @runtime_tier
end

#supportedObject

Whether TurboQuant is supported on this device



19
20
21
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 19

def supported
  @supported
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 61

def self.attribute_map
  {
    :'supported' => :'supported',
    :'recommended_model' => :'recommended_model',
    :'max_context_tokens' => :'max_context_tokens',
    :'estimated_kv_cache_gb' => :'estimated_kv_cache_gb',
    :'kv_compression_ratio' => :'kv_compression_ratio',
    :'estimated_latency_ms' => :'estimated_latency_ms',
    :'runtime_tier' => :'runtime_tier'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 215

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 84

def self.openapi_types
  {
    :'supported' => :'Boolean',
    :'recommended_model' => :'String',
    :'max_context_tokens' => :'Integer',
    :'estimated_kv_cache_gb' => :'Float',
    :'kv_compression_ratio' => :'String',
    :'estimated_latency_ms' => :'TurboQuantCapabilitiesEstimatedLatencyMs',
    :'runtime_tier' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



188
189
190
191
192
193
194
195
196
197
198
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 188

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      supported == o.supported &&
      recommended_model == o.recommended_model &&
      max_context_tokens == o.max_context_tokens &&
      estimated_kv_cache_gb == o.estimated_kv_cache_gb &&
      kv_compression_ratio == o.kv_compression_ratio &&
      estimated_latency_ms == o.estimated_latency_ms &&
      runtime_tier == o.runtime_tier
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


202
203
204
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 202

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



208
209
210
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 208

def hash
  [supported, recommended_model, max_context_tokens, estimated_kv_cache_gb, kv_compression_ratio, estimated_latency_ms, runtime_tier].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 149

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 237

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



157
158
159
160
161
162
163
164
# File 'lib/soilsidekick/models/turbo_quant_capabilities.rb', line 157

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  recommended_model_validator = EnumAttributeValidator.new('String', ["gemma-2b", "gemma-7b", "gemma-7b-tq"])
  return false unless recommended_model_validator.valid?(@recommended_model)
  runtime_tier_validator = EnumAttributeValidator.new('String', ["webgpu", "wasm_tq", "wasm_standard", "cloud_fallback"])
  return false unless runtime_tier_validator.valid?(@runtime_tier)
  true
end