Class: SoilSidekick::VisualCropAnalysisAnalysis
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SoilSidekick::VisualCropAnalysisAnalysis
- Defined in:
- lib/soilsidekick/models/visual_crop_analysis_analysis.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#analysis_type ⇒ Object
Returns the value of attribute analysis_type.
-
#confidence ⇒ Object
Returns the value of attribute confidence.
-
#findings ⇒ Object
Returns the value of attribute findings.
-
#recommendations ⇒ Object
Returns the value of attribute recommendations.
-
#severity ⇒ Object
Returns the value of attribute severity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VisualCropAnalysisAnalysis
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VisualCropAnalysisAnalysis
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::VisualCropAnalysisAnalysis` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::VisualCropAnalysisAnalysis`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'analysis_type') self.analysis_type = attributes[:'analysis_type'] end if attributes.key?(:'confidence') self.confidence = attributes[:'confidence'] end if attributes.key?(:'findings') self.findings = attributes[:'findings'] end if attributes.key?(:'recommendations') if (value = attributes[:'recommendations']).is_a?(Array) self.recommendations = value end end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end end |
Instance Attribute Details
#analysis_type ⇒ Object
Returns the value of attribute analysis_type.
18 19 20 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 18 def analysis_type @analysis_type end |
#confidence ⇒ Object
Returns the value of attribute confidence.
20 21 22 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 20 def confidence @confidence end |
#findings ⇒ Object
Returns the value of attribute findings.
22 23 24 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 22 def findings @findings end |
#recommendations ⇒ Object
Returns the value of attribute recommendations.
24 25 26 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 24 def recommendations @recommendations end |
#severity ⇒ Object
Returns the value of attribute severity.
26 27 28 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 26 def severity @severity end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 51 def self.attribute_map { :'analysis_type' => :'analysis_type', :'confidence' => :'confidence', :'findings' => :'findings', :'recommendations' => :'recommendations', :'severity' => :'severity' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 181 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 83 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 72 def self.openapi_types { :'analysis_type' => :'String', :'confidence' => :'Float', :'findings' => :'Object', :'recommendations' => :'Array<String>', :'severity' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
156 157 158 159 160 161 162 163 164 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 156 def ==(o) return true if self.equal?(o) self.class == o.class && analysis_type == o.analysis_type && confidence == o.confidence && findings == o.findings && recommendations == o.recommendations && severity == o.severity end |
#eql?(o) ⇒ Boolean
168 169 170 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 168 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 174 def hash [analysis_type, confidence, findings, recommendations, severity].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 141 142 |
# File 'lib/soilsidekick/models/visual_crop_analysis_analysis.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' severity_validator = EnumAttributeValidator.new('String', ["low", "medium", "high"]) return false unless severity_validator.valid?(@severity) true end |