Class: SoilSidekick::VisualCropAnalysisRequestLocation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SoilSidekick::VisualCropAnalysisRequestLocation
- Defined in:
- lib/soilsidekick/models/visual_crop_analysis_request_location.rb
Instance Attribute Summary collapse
-
#county_fips ⇒ Object
Returns the value of attribute county_fips.
-
#county_name ⇒ Object
Returns the value of attribute county_name.
-
#state_code ⇒ Object
Returns the value of attribute state_code.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VisualCropAnalysisRequestLocation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VisualCropAnalysisRequestLocation
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 60 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::VisualCropAnalysisRequestLocation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::VisualCropAnalysisRequestLocation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'county_fips') self.county_fips = attributes[:'county_fips'] end if attributes.key?(:'county_name') self.county_name = attributes[:'county_name'] end if attributes.key?(:'state_code') self.state_code = attributes[:'state_code'] end end |
Instance Attribute Details
#county_fips ⇒ Object
Returns the value of attribute county_fips.
18 19 20 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 18 def county_fips @county_fips end |
#county_name ⇒ Object
Returns the value of attribute county_name.
20 21 22 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 20 def county_name @county_name end |
#state_code ⇒ Object
Returns the value of attribute state_code.
22 23 24 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 22 def state_code @state_code end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 25 def self.attribute_map { :'county_fips' => :'county_fips', :'county_name' => :'county_name', :'state_code' => :'state_code' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 127 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
53 54 55 56 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 53 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 44 def self.openapi_types { :'county_fips' => :'String', :'county_name' => :'String', :'state_code' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
104 105 106 107 108 109 110 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 104 def ==(o) return true if self.equal?(o) self.class == o.class && county_fips == o.county_fips && county_name == o.county_name && state_code == o.state_code end |
#eql?(o) ⇒ Boolean
114 115 116 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 114 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
120 121 122 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 120 def hash [county_fips, county_name, state_code].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
89 90 91 92 93 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 89 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 149 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
97 98 99 100 |
# File 'lib/soilsidekick/models/visual_crop_analysis_request_location.rb', line 97 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |