Class: SoilSidekick::WaterQuality
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SoilSidekick::WaterQuality
- Defined in:
- lib/soilsidekick/models/water_quality.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#contamination_risk ⇒ Object
Returns the value of attribute contamination_risk.
-
#county_fips ⇒ Object
Returns the value of attribute county_fips.
-
#dissolved_oxygen ⇒ Object
Returns the value of attribute dissolved_oxygen.
-
#nitrates ⇒ Object
Returns the value of attribute nitrates.
-
#ph ⇒ Object
Returns the value of attribute ph.
-
#phosphates ⇒ Object
Returns the value of attribute phosphates.
-
#turbidity ⇒ Object
Returns the value of attribute turbidity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WaterQuality
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WaterQuality
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/soilsidekick/models/water_quality.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::WaterQuality` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::WaterQuality`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'county_fips') self.county_fips = attributes[:'county_fips'] end if attributes.key?(:'ph') self.ph = attributes[:'ph'] end if attributes.key?(:'dissolved_oxygen') self.dissolved_oxygen = attributes[:'dissolved_oxygen'] end if attributes.key?(:'turbidity') self.turbidity = attributes[:'turbidity'] end if attributes.key?(:'nitrates') self.nitrates = attributes[:'nitrates'] end if attributes.key?(:'phosphates') self.phosphates = attributes[:'phosphates'] end if attributes.key?(:'contamination_risk') self.contamination_risk = attributes[:'contamination_risk'] end end |
Instance Attribute Details
#contamination_risk ⇒ Object
Returns the value of attribute contamination_risk.
30 31 32 |
# File 'lib/soilsidekick/models/water_quality.rb', line 30 def contamination_risk @contamination_risk end |
#county_fips ⇒ Object
Returns the value of attribute county_fips.
18 19 20 |
# File 'lib/soilsidekick/models/water_quality.rb', line 18 def county_fips @county_fips end |
#dissolved_oxygen ⇒ Object
Returns the value of attribute dissolved_oxygen.
22 23 24 |
# File 'lib/soilsidekick/models/water_quality.rb', line 22 def dissolved_oxygen @dissolved_oxygen end |
#nitrates ⇒ Object
Returns the value of attribute nitrates.
26 27 28 |
# File 'lib/soilsidekick/models/water_quality.rb', line 26 def nitrates @nitrates end |
#ph ⇒ Object
Returns the value of attribute ph.
20 21 22 |
# File 'lib/soilsidekick/models/water_quality.rb', line 20 def ph @ph end |
#phosphates ⇒ Object
Returns the value of attribute phosphates.
28 29 30 |
# File 'lib/soilsidekick/models/water_quality.rb', line 28 def phosphates @phosphates end |
#turbidity ⇒ Object
Returns the value of attribute turbidity.
24 25 26 |
# File 'lib/soilsidekick/models/water_quality.rb', line 24 def turbidity @turbidity end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/soilsidekick/models/water_quality.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/soilsidekick/models/water_quality.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/soilsidekick/models/water_quality.rb', line 55 def self.attribute_map { :'county_fips' => :'county_fips', :'ph' => :'ph', :'dissolved_oxygen' => :'dissolved_oxygen', :'turbidity' => :'turbidity', :'nitrates' => :'nitrates', :'phosphates' => :'phosphates', :'contamination_risk' => :'contamination_risk' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/soilsidekick/models/water_quality.rb', line 197 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/soilsidekick/models/water_quality.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/soilsidekick/models/water_quality.rb', line 78 def self.openapi_types { :'county_fips' => :'String', :'ph' => :'Float', :'dissolved_oxygen' => :'Float', :'turbidity' => :'Float', :'nitrates' => :'Float', :'phosphates' => :'Float', :'contamination_risk' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/soilsidekick/models/water_quality.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && county_fips == o.county_fips && ph == o.ph && dissolved_oxygen == o.dissolved_oxygen && turbidity == o.turbidity && nitrates == o.nitrates && phosphates == o.phosphates && contamination_risk == o.contamination_risk end |
#eql?(o) ⇒ Boolean
184 185 186 |
# File 'lib/soilsidekick/models/water_quality.rb', line 184 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
190 191 192 |
# File 'lib/soilsidekick/models/water_quality.rb', line 190 def hash [county_fips, ph, dissolved_oxygen, turbidity, nitrates, phosphates, contamination_risk].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
143 144 145 146 147 |
# File 'lib/soilsidekick/models/water_quality.rb', line 143 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/soilsidekick/models/water_quality.rb', line 219 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
151 152 153 154 155 156 |
# File 'lib/soilsidekick/models/water_quality.rb', line 151 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' contamination_risk_validator = EnumAttributeValidator.new('String', ["low", "medium", "high"]) return false unless contamination_risk_validator.valid?(@contamination_risk) true end |