Class: SoilSidekick::BeginnerGuidance
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SoilSidekick::BeginnerGuidance
- Defined in:
- lib/soilsidekick/models/beginner_guidance.rb
Overview
Beginner-friendly plant guidance response
Instance Attribute Summary collapse
-
#confidence ⇒ Object
Confidence in the guidance (0-100).
-
#detailed_explanation ⇒ Object
Returns the value of attribute detailed_explanation.
-
#encouragement ⇒ Object
Supportive message for the user.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#related_questions ⇒ Object
Common follow-up questions.
-
#simple_answer ⇒ Object
Plain-language answer without jargon, 1-2 sentences.
-
#success ⇒ Object
Returns the value of attribute success.
-
#what_to_do_now ⇒ Object
Immediate actionable step.
-
#why_this_happens ⇒ Object
Simple explanation of the cause.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BeginnerGuidance
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BeginnerGuidance
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 91 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::BeginnerGuidance` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::BeginnerGuidance`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'success') self.success = attributes[:'success'] end if attributes.key?(:'simple_answer') self.simple_answer = attributes[:'simple_answer'] end if attributes.key?(:'what_to_do_now') self.what_to_do_now = attributes[:'what_to_do_now'] end if attributes.key?(:'why_this_happens') self.why_this_happens = attributes[:'why_this_happens'] end if attributes.key?(:'detailed_explanation') self.detailed_explanation = attributes[:'detailed_explanation'] end if attributes.key?(:'encouragement') self.encouragement = attributes[:'encouragement'] end if attributes.key?(:'related_questions') if (value = attributes[:'related_questions']).is_a?(Array) self. = value end end if attributes.key?(:'confidence') self.confidence = attributes[:'confidence'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end end |
Instance Attribute Details
#confidence ⇒ Object
Confidence in the guidance (0-100)
39 40 41 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 39 def confidence @confidence end |
#detailed_explanation ⇒ Object
Returns the value of attribute detailed_explanation.
30 31 32 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 30 def detailed_explanation @detailed_explanation end |
#encouragement ⇒ Object
Supportive message for the user
33 34 35 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 33 def encouragement @encouragement end |
#metadata ⇒ Object
Returns the value of attribute metadata.
41 42 43 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 41 def @metadata end |
#related_questions ⇒ Object
Common follow-up questions
36 37 38 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 36 def @related_questions end |
#simple_answer ⇒ Object
Plain-language answer without jargon, 1-2 sentences
22 23 24 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 22 def simple_answer @simple_answer end |
#success ⇒ Object
Returns the value of attribute success.
19 20 21 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 19 def success @success end |
#what_to_do_now ⇒ Object
Immediate actionable step
25 26 27 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 25 def what_to_do_now @what_to_do_now end |
#why_this_happens ⇒ Object
Simple explanation of the cause
28 29 30 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 28 def why_this_happens @why_this_happens end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 44 def self.attribute_map { :'success' => :'success', :'simple_answer' => :'simple_answer', :'what_to_do_now' => :'what_to_do_now', :'why_this_happens' => :'why_this_happens', :'detailed_explanation' => :'detailed_explanation', :'encouragement' => :'encouragement', :'related_questions' => :'related_questions', :'confidence' => :'confidence', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 190 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 84 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 69 def self.openapi_types { :'success' => :'Boolean', :'simple_answer' => :'String', :'what_to_do_now' => :'String', :'why_this_happens' => :'String', :'detailed_explanation' => :'BeginnerGuidanceDetailedExplanation', :'encouragement' => :'String', :'related_questions' => :'Array<String>', :'confidence' => :'Float', :'metadata' => :'BeginnerGuidanceMetadata' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && success == o.success && simple_answer == o.simple_answer && what_to_do_now == o.what_to_do_now && why_this_happens == o.why_this_happens && detailed_explanation == o.detailed_explanation && encouragement == o.encouragement && == o. && confidence == o.confidence && == o. end |
#eql?(o) ⇒ Boolean
177 178 179 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 177 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 183 def hash [success, simple_answer, what_to_do_now, why_this_happens, detailed_explanation, encouragement, , confidence, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 212 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 |
# File 'lib/soilsidekick/models/beginner_guidance.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |