Class: SoilSidekick::DynamicCare
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SoilSidekick::DynamicCare
- Defined in:
- lib/soilsidekick/models/dynamic_care.rb
Overview
Dynamic, environment-aware plant care recommendations
Instance Attribute Summary collapse
-
#care_recommendations ⇒ Object
Returns the value of attribute care_recommendations.
-
#current_conditions ⇒ Object
Returns the value of attribute current_conditions.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#plant ⇒ Object
Returns the value of attribute plant.
-
#success ⇒ Object
Returns the value of attribute success.
-
#warnings ⇒ Object
Any urgent care warnings.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DynamicCare
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DynamicCare
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::DynamicCare` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::DynamicCare`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'success') self.success = attributes[:'success'] end if attributes.key?(:'plant') self.plant = attributes[:'plant'] end if attributes.key?(:'current_conditions') self.current_conditions = attributes[:'current_conditions'] end if attributes.key?(:'care_recommendations') self.care_recommendations = attributes[:'care_recommendations'] end if attributes.key?(:'warnings') if (value = attributes[:'warnings']).is_a?(Array) self.warnings = value end end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end end |
Instance Attribute Details
#care_recommendations ⇒ Object
Returns the value of attribute care_recommendations.
25 26 27 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 25 def care_recommendations @care_recommendations end |
#current_conditions ⇒ Object
Returns the value of attribute current_conditions.
23 24 25 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 23 def current_conditions @current_conditions end |
#metadata ⇒ Object
Returns the value of attribute metadata.
30 31 32 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 30 def @metadata end |
#plant ⇒ Object
Returns the value of attribute plant.
21 22 23 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 21 def plant @plant end |
#success ⇒ Object
Returns the value of attribute success.
19 20 21 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 19 def success @success end |
#warnings ⇒ Object
Any urgent care warnings
28 29 30 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 28 def warnings @warnings end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 33 def self.attribute_map { :'success' => :'success', :'plant' => :'plant', :'current_conditions' => :'current_conditions', :'care_recommendations' => :'care_recommendations', :'warnings' => :'warnings', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 158 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 67 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 55 def self.openapi_types { :'success' => :'Boolean', :'plant' => :'DynamicCarePlant', :'current_conditions' => :'DynamicCareCurrentConditions', :'care_recommendations' => :'DynamicCareCareRecommendations', :'warnings' => :'Array<String>', :'metadata' => :'DynamicCareMetadata' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 132 def ==(o) return true if self.equal?(o) self.class == o.class && success == o.success && plant == o.plant && current_conditions == o.current_conditions && care_recommendations == o.care_recommendations && warnings == o.warnings && == o. end |
#eql?(o) ⇒ Boolean
145 146 147 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 145 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 151 def hash [success, plant, current_conditions, care_recommendations, warnings, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 117 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
125 126 127 128 |
# File 'lib/soilsidekick/models/dynamic_care.rb', line 125 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |