Class: SoilSidekick::SoilData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SoilSidekick::SoilData
- Defined in:
- lib/soilsidekick/models/soil_data.rb
Instance Attribute Summary collapse
-
#analysis_data ⇒ Object
Returns the value of attribute analysis_data.
-
#county_fips ⇒ Object
Returns the value of attribute county_fips.
-
#county_name ⇒ Object
Returns the value of attribute county_name.
-
#id ⇒ Object
Returns the value of attribute id.
-
#nitrogen_level ⇒ Object
Returns the value of attribute nitrogen_level.
-
#organic_matter ⇒ Object
Returns the value of attribute organic_matter.
-
#ph_level ⇒ Object
Returns the value of attribute ph_level.
-
#phosphorus_level ⇒ Object
Returns the value of attribute phosphorus_level.
-
#potassium_level ⇒ Object
Returns the value of attribute potassium_level.
-
#recommendations ⇒ Object
Returns the value of attribute recommendations.
-
#state_code ⇒ Object
Returns the value of attribute state_code.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SoilData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SoilData
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/soilsidekick/models/soil_data.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SoilSidekick::SoilData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SoilSidekick::SoilData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'county_fips') self.county_fips = attributes[:'county_fips'] end if attributes.key?(:'county_name') self.county_name = attributes[:'county_name'] end if attributes.key?(:'state_code') self.state_code = attributes[:'state_code'] end if attributes.key?(:'ph_level') self.ph_level = attributes[:'ph_level'] end if attributes.key?(:'organic_matter') self.organic_matter = attributes[:'organic_matter'] end if attributes.key?(:'nitrogen_level') self.nitrogen_level = attributes[:'nitrogen_level'] end if attributes.key?(:'phosphorus_level') self.phosphorus_level = attributes[:'phosphorus_level'] end if attributes.key?(:'potassium_level') self.potassium_level = attributes[:'potassium_level'] end if attributes.key?(:'recommendations') self.recommendations = attributes[:'recommendations'] end if attributes.key?(:'analysis_data') if (value = attributes[:'analysis_data']).is_a?(Hash) self.analysis_data = value end end end |
Instance Attribute Details
#analysis_data ⇒ Object
Returns the value of attribute analysis_data.
38 39 40 |
# File 'lib/soilsidekick/models/soil_data.rb', line 38 def analysis_data @analysis_data end |
#county_fips ⇒ Object
Returns the value of attribute county_fips.
20 21 22 |
# File 'lib/soilsidekick/models/soil_data.rb', line 20 def county_fips @county_fips end |
#county_name ⇒ Object
Returns the value of attribute county_name.
22 23 24 |
# File 'lib/soilsidekick/models/soil_data.rb', line 22 def county_name @county_name end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/soilsidekick/models/soil_data.rb', line 18 def id @id end |
#nitrogen_level ⇒ Object
Returns the value of attribute nitrogen_level.
30 31 32 |
# File 'lib/soilsidekick/models/soil_data.rb', line 30 def nitrogen_level @nitrogen_level end |
#organic_matter ⇒ Object
Returns the value of attribute organic_matter.
28 29 30 |
# File 'lib/soilsidekick/models/soil_data.rb', line 28 def organic_matter @organic_matter end |
#ph_level ⇒ Object
Returns the value of attribute ph_level.
26 27 28 |
# File 'lib/soilsidekick/models/soil_data.rb', line 26 def ph_level @ph_level end |
#phosphorus_level ⇒ Object
Returns the value of attribute phosphorus_level.
32 33 34 |
# File 'lib/soilsidekick/models/soil_data.rb', line 32 def phosphorus_level @phosphorus_level end |
#potassium_level ⇒ Object
Returns the value of attribute potassium_level.
34 35 36 |
# File 'lib/soilsidekick/models/soil_data.rb', line 34 def potassium_level @potassium_level end |
#recommendations ⇒ Object
Returns the value of attribute recommendations.
36 37 38 |
# File 'lib/soilsidekick/models/soil_data.rb', line 36 def recommendations @recommendations end |
#state_code ⇒ Object
Returns the value of attribute state_code.
24 25 26 |
# File 'lib/soilsidekick/models/soil_data.rb', line 24 def state_code @state_code end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/soilsidekick/models/soil_data.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/soilsidekick/models/soil_data.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/soilsidekick/models/soil_data.rb', line 41 def self.attribute_map { :'id' => :'id', :'county_fips' => :'county_fips', :'county_name' => :'county_name', :'state_code' => :'state_code', :'ph_level' => :'ph_level', :'organic_matter' => :'organic_matter', :'nitrogen_level' => :'nitrogen_level', :'phosphorus_level' => :'phosphorus_level', :'potassium_level' => :'potassium_level', :'recommendations' => :'recommendations', :'analysis_data' => :'analysis_data' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/soilsidekick/models/soil_data.rb', line 201 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/soilsidekick/models/soil_data.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/soilsidekick/models/soil_data.rb', line 68 def self.openapi_types { :'id' => :'String', :'county_fips' => :'String', :'county_name' => :'String', :'state_code' => :'String', :'ph_level' => :'Float', :'organic_matter' => :'Float', :'nitrogen_level' => :'String', :'phosphorus_level' => :'String', :'potassium_level' => :'String', :'recommendations' => :'String', :'analysis_data' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/soilsidekick/models/soil_data.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && county_fips == o.county_fips && county_name == o.county_name && state_code == o.state_code && ph_level == o.ph_level && organic_matter == o.organic_matter && nitrogen_level == o.nitrogen_level && phosphorus_level == o.phosphorus_level && potassium_level == o.potassium_level && recommendations == o.recommendations && analysis_data == o.analysis_data end |
#eql?(o) ⇒ Boolean
188 189 190 |
# File 'lib/soilsidekick/models/soil_data.rb', line 188 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/soilsidekick/models/soil_data.rb', line 194 def hash [id, county_fips, county_name, state_code, ph_level, organic_matter, nitrogen_level, phosphorus_level, potassium_level, recommendations, analysis_data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 |
# File 'lib/soilsidekick/models/soil_data.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/soilsidekick/models/soil_data.rb', line 223 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 |
# File 'lib/soilsidekick/models/soil_data.rb', line 163 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |